Class: Emeril::RakeTasks
- Inherits:
-
Rake::TaskLib
- Object
- Rake::TaskLib
- Emeril::RakeTasks
- Defined in:
- lib/emeril/rake_tasks.rb
Overview
Emeril Rake task generator.
Instance Attribute Summary collapse
-
#config ⇒ Object
Returns the value of attribute config.
Instance Method Summary collapse
-
#initialize {|self| ... } ⇒ RakeTasks
constructor
Creates Emeril Rake tasks and allows the callee to configure it.
Constructor Details
#initialize {|self| ... } ⇒ RakeTasks
Creates Emeril Rake tasks and allows the callee to configure it.
22 23 24 25 26 |
# File 'lib/emeril/rake_tasks.rb', line 22 def initialize @config = { :logger => Chef::Log } yield self if block_given? define end |
Instance Attribute Details
#config ⇒ Object
Returns the value of attribute config.
16 17 18 |
# File 'lib/emeril/rake_tasks.rb', line 16 def config @config end |