Class: Emeril::ThorTasks
- Inherits:
-
Thor
- Object
- Thor
- Emeril::ThorTasks
- Defined in:
- lib/emeril/thor_tasks.rb
Overview
Emeril Rake task generator.
Instance Attribute Summary collapse
-
#config ⇒ Object
Returns the value of attribute config.
Instance Method Summary collapse
-
#initialize(*args) {|self| ... } ⇒ ThorTasks
constructor
Creates Emeril Thor tasks and allows the callee to configure it.
Constructor Details
#initialize(*args) {|self| ... } ⇒ ThorTasks
Creates Emeril Thor tasks and allows the callee to configure it.
24 25 26 27 28 29 |
# File 'lib/emeril/thor_tasks.rb', line 24 def initialize(*args) super @config = { :logger => Chef::Log } yield self if block_given? define end |
Instance Attribute Details
#config ⇒ Object
Returns the value of attribute config.
18 19 20 |
# File 'lib/emeril/thor_tasks.rb', line 18 def config @config end |