Class: Emeril::Publisher::SharePlugin
- Inherits:
-
Chef::Knife::CookbookSiteShare
- Object
- Chef::Knife::CookbookSiteShare
- Emeril::Publisher::SharePlugin
- Defined in:
- lib/emeril/publisher.rb
Overview
A custom cookbook site share knife plugin that intercepts Kernel#exit calls and converts them to an exception raise.
Instance Method Summary collapse
Instance Method Details
#exit(code) ⇒ Object
127 128 129 |
# File 'lib/emeril/publisher.rb', line 127 def exit(code) raise "Knife Plugin exited with error code: #{code}" end |